#pragma once

#if PLATFORM_ANDROID

#include "Android/AndroidApplication.h"
#include "Android/AndroidJNI.h"

#endif

enum AirbridgeCallbackType
{
 HandleDeeplink,
 HandleDeferredDeeplink,
 Click,
 Impression,
 FetchDeviceUUID,
 FetchAirbridgeGeneratedUUID,
};

#if PLATFORM_ANDROID

/**
 * Retrieves the callback type from a Java object.
 *
 * @param Env JNI environment pointer.
 * @param This Java object for which to retrieve the callback type.
 * @return The callback type as an integer, or -1 if the method is not found.
 */
jint GetCallbackType(JNIEnv *Env, jobject This);

/**
 * Retrieves the callback UUID from a Java object.
 *
 * @param Env JNI environment pointer.
 * @param This Java object for which to retrieve the callback UUID.
 * @return The callback UUID as an FString, or empty string if the method is not found.
 */
FString GetCallbackUUID(JNIEnv *Env, jobject This);

bool IsBroadcastCallback(JNIEnv *Env, jobject This);

/**
 * Convert the Java string to FString.
 */
FString ConvertString(JNIEnv *Env, jstring String);

/**
 * Convert the Java Uri to FString.
 */
FString GetUriString(JNIEnv *Env, jobject Result);

#endif