// Copyright © 2023 ab180. All rights reserved.
#pragma once

#include "EngineMinimal.h"
#include "Airbridge/Container/AirbridgeMap.h"

typedef	TFunction<void(const FString&)>						AirbridgeStringParamFunction;
typedef	TFunction<void(const TMap<FString, FString>&)>		AirbridgeMapParamFunction;
typedef	TFunction<void()>									AirbridgeVoidParamFunction;

class IAirbridgeCore
{
public:

#pragma region Core

	virtual void EnableSDK() = 0;
	virtual void DisableSDK() = 0;
	virtual bool IsSDKEnabled() = 0;

	// virtual void StartInAppPurchaseTracking() = 0;
	// virtual void StopInAppPurchaseTracking() = 0;
	// virtual bool IsInAppPurchaseTrackingEnabled() = 0;
    
#pragma endregion

#pragma region Privacy

	virtual void StartTracking() = 0;
	virtual void StopTracking() = 0;
	virtual bool IsTrackingEnabled() = 0;
    
#pragma endregion

#pragma region Deeplink

	virtual void SetOnDeeplinkReceived(
		const AirbridgeStringParamFunction OnDeeplinkReceived,
		bool UseBroadcast = false
	) = 0;
    
#pragma endregion

#pragma region Data Collection

	virtual void SetUserID(const FString& Id) = 0;
	virtual void ClearUserID() = 0;
	virtual void SetUserEmail(const FString& Email) = 0;
	virtual void ClearUserEmail() = 0;
	virtual void SetUserPhone(const FString& Phone) = 0;
	virtual void ClearUserPhone() = 0;
	virtual void SetUserAttribute(const FString& Key, const int32 Value) = 0;
	virtual void SetUserAttribute(const FString& Key, const int64 Value) = 0;
	virtual void SetUserAttribute(const FString& Key, const float Value) = 0;
	virtual void SetUserAttribute(const FString& Key, const double Value) = 0;
	virtual void SetUserAttribute(const FString& Key, const bool Value) = 0;
	virtual void SetUserAttribute(const FString& Key, const FString& Value) = 0;
	virtual void RemoveUserAttribute(const FString& Key) = 0;
	virtual void ClearUserAttributes() = 0;
	virtual void SetUserAlias(const FString& Key, const FString& Value) = 0;
	virtual void RemoveUserAlias(const FString& Key) = 0;
	virtual void ClearUserAlias() = 0;
	virtual void ClearUser() = 0;

	virtual void SetDeviceAlias(const FString& Key, const FString& Value) = 0;
	virtual void RemoveDeviceAlias(const FString& Key) = 0;
	virtual void ClearDeviceAlias() = 0;

	virtual void RegisterPushToken(const FString& Token) = 0;

#pragma endregion 

#pragma region Event
	
	virtual void TrackEvent(
		const FString& Category,
		const UAirbridgeMap* SemanticAttributes = nullptr,
		const UAirbridgeMap* CustomAttributes = nullptr
	) = 0;

#pragma endregion

#pragma region Placement

	virtual void Click(
		const FString& TrackingLink,
		const AirbridgeVoidParamFunction OnSuccess = nullptr,
		const AirbridgeStringParamFunction OnFailure = nullptr
	) = 0;
	virtual void Impression(
		const FString& TrackingLink,
		const AirbridgeVoidParamFunction OnSuccess = nullptr,
		const AirbridgeStringParamFunction OnFailure = nullptr
	) = 0;

#pragma endregion

#pragma region Publication
	
	virtual void FetchDeviceUUID(
		const AirbridgeStringParamFunction OnSuccess,
		const AirbridgeStringParamFunction OnFailure = nullptr,
		bool UseBroadcast = false
	) = 0;
	virtual void FetchAirbridgeGeneratedUUID(
		const AirbridgeStringParamFunction OnSuccess,
		const AirbridgeStringParamFunction OnFailure = nullptr,
		bool UseBroadcast = false
	) = 0;
	virtual void SetOnAttributionReceived(
		const AirbridgeMapParamFunction OnAttributionReceived,
		bool UseBroadcast = false
	) = 0;

#pragma endregion 

#pragma region Hybrid

	virtual FString CreateWebInterfaceScript(const FString& WebToken, const FString& PostMessageScript) = 0;
	virtual void HandleWebInterfaceCommand(const FString& Command) = 0;

#pragma endregion
};